@@ -1,5 +1,5 @@
 package Text::Quoted;
-our $VERSION = "2.03";
+our $VERSION = "2.04";
 use 5.006;
 use strict;
 use warnings;
@@ -10,7 +10,6 @@ our @ISA    = qw(Exporter);
 our @EXPORT = qw(extract);
 
 use Text::Autoformat();    # Provides the Hang package, heh, heh.
-use Text::Tabs();
 
 =head1 NAME
 
@@ -169,11 +168,9 @@ sub classify {
     # If the user passes in a null string, we really want to end up with _something_
 
     # DETABIFY
-    my @lines = Text::Tabs::expand( split /\n/, $text );
-
+    my @lines = expand_tabs( split /\n/, $text );
 
     # PARSE EACH LINE
-
     foreach (splice @lines) {
         my %line = ( raw => $_ );
         @line{'quoter', 'text'} = (/\A *($quoter?) *(.*?)\s*\Z/o);
@@ -233,4 +230,22 @@ sub classify {
     return @paras;
 }
 
+# we don't use Text::Tabs anymore as it may segfault on perl 5.8.x with
+# UTF-8 strings and tabs mixed. http://rt.perl.org/rt3/Public/Bug/Display.html?id=40989
+# This bug unlikely to be fixed in 5.8.x, however we use workaround.
+# As soon as Text::Tabs will be fixed we can return back to it
+my $tabstop = 8;
+sub expand_tabs {
+    my $pad;
+    for ( @_ ) {
+        my $offs = 0;
+        s{(.*?)\t}{
+            $pad = $tabstop - (length($1) + $offs) % $tabstop;
+            $offs += length($1)+$pad;
+            $1 . (" " x $pad);
+        }eg;
+    }
+    return @_;
+}
+
 1;
